<?php
/*  Copyright 2002-2003 Patrick R. Michaud (pmichaud@pobox.com)
    This file is part of PmWiki; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published
    by the Free Software Foundation; either version 2 of the License
    (at your option) any later version.  See pmwiki.php for full details.

    This script enables email notifications to be sent whenever posts
    are made.  It is included by default from the stdconfig.php 
    script if $EnableMailPosts is set to non-zero.  Be sure to set
    the $MailPostsTo variable or the scratch file will grow without
    limit.

    To explicitly enable this feature, execute
	include_once("scripts/mailposts.php");
    from local.php somewhere.

    Several variables control the functioning of this script:

    $MailPostsTo - comma separated list of email recipients
    $MailPostsDelay - number of seconds to wait before sending mail after
      the first post.  Useful so that lots of small edits result are 
      batched together in a single email message.  However, mail
      won't be sent until the first execution of pmwiki.php after the
      delay has expired, which could be much longer than the delay period
      itself depending on how active your site is.
    $MailPostsSquelch - minimum number of seconds between sending mail
      messages.  Useful when $MailPostsDelay is set to a small value
      to prevent large numbers of mail notifications to be sent.
    $MailPostsFile - scratch file used to keep track of recent posts
    $MailPostsMessage - array of strings to be sent at beginning of message
    $MailPostsSubject - subject line for mail to be sent
    $MailPostsHeaders - string of extra headers for mail (passed to PHP
       mail() function, some headers may not work for PHP < 4.3).
*/

if (!isset($MailPostsDelay)) $MailPostsDelay=0;
if (!isset($MailPostsSquelch)) $MailPostsSquelch=7200;
if (!isset($MailPostsFile)) $MailPostsFile="$WikiDir/.mailposts";
if (!isset($MailPostsMessage)) $MailPostsMessage=array("Recent posts:\n\n");
if (!isset($MailPostsSubject)) $MailPostsSubject="$WikiTitle recent wiki posts";

if ($action=='post') {
  Lock(2);
  $fp = @fopen($MailPostsFile,"a");
  if ($fp) { fputs($fp,"$Now $pagename\n"); fclose($fp); }
  Lock(0);
}

if ($MailPostsTo=="") return;
$fp = @fopen($MailPostsFile,"r");
if (!$fp) return;
$oldestpost = $Now+1; $mailpost=array();
while (!feof($fp)) {
  list($t,$p) = explode(' ',rtrim(fgets($fp,1024)));
  if (!$t) continue;
  if ($p=='#lastmailed') {
    if ($t > $Now-$MailPostsSquelch) { fclose($fp); return; }
    continue;
  }
  Lock(2);
  array_push($MailPostsMessage,strftime($TimeFmt,$t)." - $p\n");
  if ($t<$oldestpost) $oldestpost=$t;
}
fclose($fp);

if ($oldestpost > $Now-$MailPostsDelay) { Lock(0); return; }
@mail($MailPostsTo,$MailPostsSubject,implode("",$MailPostsMessage),
  $MailPostHeaders);

$fp = @fopen($MailPostsFile,"w");
if ($fp) { fputs($fp,"$Now #lastmailed\n"); fclose($fp); }
Lock(0);
?>
